CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_utils.c File Reference

CCL

Functions
ccl_test_utils.c File Reference
`#include "ccl.h"`
`#include "ctest.h"`
`#include "ccl_params.h"`
`#include "ccl_core.h"`

## Functions
| CTEST (spacing_tests, linear_spacing_simple)
| CTEST (spacing_tests, linear_spacing_spline_limits)

## Function Documentation

## ◆ CTEST() [1/2]

CTEST | ( | spacing_tests | ,
|  | linear_spacing_simple |
| ) |  |

## ◆ CTEST() [2/2]

CTEST | ( | spacing_tests | ,
|  | linear_spacing_spline_limits |
| ) |  |